pamqp
=====

pamqp is a pure-python AMQP 0-9-1 frame encoder and decoder. The aim is to create a
client agnostic python encoder and decoder for general purpose use.

|PyPI version| |Downloads| |Build Status| |Coverage| |License|

Documentation
-------------
http://pamqp.readthedocs.org

License
-------
BSD

Python Versions Supported
-------------------------
2.6+, 3.2+

Requirements
------------
codegen (not required for use) requires lxml.

.. |PyPI version| image:: https://badge.fury.io/py/pamqp.svg?
   :target: http://badge.fury.io/py/pamqp
   
.. |Downloads| image:: https://pypip.in/d/pamqp/badge.svg?
   :target: https://pypi.python.org/pypi/pamqp

.. |Build Status| image:: https://travis-ci.org/gmr/pamqp.png?branch=master
   :target: https://travis-ci.org/gmr/pamqp
   
.. |Coverage| image:: https://coveralls.io/repos/gmr/pamqp/badge.png
   :target: https://coveralls.io/r/gmr/rabbitpy

.. |License| image:: https://pypip.in/license/pamqp/badge.svg?
   :target: https://pypi.python.org/pypi/pamqp
